[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![on PyPI](https://badge.fury.io/py/pyfuppes.svg)](https://badge.fury.io/py/pyfuppes)

# pyFuppes

A collection of tools in Python, mostly revolving around time series data analysis. Caution: this package is pretty dependency-heavy.

## License

`GPLv3` - see LICENSE.md file in the root directory of the repository.
